==> apache-camel-4.10.9-src.zip: apache-camel-4.10.9/core/camel-management/src/main/java/org/apache/camel/management/mbean/ManagedDisabled.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.management.mbean;

import org.apache.camel.CamelContext;
import org.apache.camel.api.management.ManagedResource;
import org.apache.camel.api.management.mbean.ManagedDisabledMBean;
import org.apache.camel.model.ProcessorDefinition;
import org.apache.camel.processor.DisabledProcessor;

@ManagedResource(description = "Managed Disabled Processor")
public class ManagedDisabled extends ManagedProcessor implements ManagedDisabledMBean {
    private final DisabledProcessor processor;

    public ManagedDisabled(CamelContext context, DisabledProcessor processor, ProcessorDefinition<?> definition) {
        super(context, processor, definition);
        this.processor = processor;
    }

    @Override
    public String getNodeType() {
        return processor.getNodeType();
    }
}

==> apache-camel-4.14.2-src.zip: apache-camel-4.14.2/core/camel-management/src/main/java/org/apache/camel/management/mbean/ManagedDisabled.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.management.mbean;

import org.apache.camel.CamelContext;
import org.apache.camel.api.management.ManagedResource;
import org.apache.camel.api.management.mbean.ManagedDisabledMBean;
import org.apache.camel.model.ProcessorDefinition;
import org.apache.camel.processor.DisabledProcessor;

@ManagedResource(description = "Managed Disabled Processor")
public class ManagedDisabled extends ManagedProcessor implements ManagedDisabledMBean {

    public ManagedDisabled(CamelContext context, DisabledProcessor processor, ProcessorDefinition<?> definition) {
        super(context, processor, definition);
    }

    @Override
    public DisabledProcessor getProcessor() {
        return (DisabledProcessor) super.getProcessor();
    }

    @Override
    public String getNodeType() {
        return getProcessor().getNodeType();
    }
}
